@@ -14,6 +14,9 @@ from thrift_files.libraries.thrift_hive_metastore_client.ttypes import (  # type
     FieldSchema,
     Database,
     AlreadyExistsException,
+    Table,
+    PartitionValuesRequest,
+    NoSuchObjectException,
 )
 
 
@@ -113,16 +116,24 @@ class HiveMetastoreClient(ThriftClient):
             # call alter table to drop columns removed from list of table columns
             self.alter_table(dbname=db_name, tbl_name=table_name, new_tbl=table)
 
-    def add_partitions_to_table(
+    def add_partitions_if_not_exists(
         self, db_name: str, table_name: str, partition_list: List[Partition]
     ) -> None:
         """
-        Add partitions to a table.
+        Add partitions to a table if it does not exist.
+
+        If the user tries to add a partition twice, the method handles the
+         AlreadyExistsException, not raising an error.
 
         :param db_name: database name where the table is at
         :param table_name: table name which the partitions belong to
         :param partition_list: list of partitions to be added to the table
         """
+        if not partition_list:
+            raise ValueError(
+                "m=add_partitions_if_not_exists, msg=The partition list is empty."
+            )
+
         table = self.get_table(dbname=db_name, tbl_name=table_name)
 
         partition_list_with_correct_location = self._format_partitions_location(
@@ -131,9 +142,12 @@ class HiveMetastoreClient(ThriftClient):
             table_partition_keys=table.partitionKeys,
         )
 
-        self.add_partitions(partition_list_with_correct_location)
+        try:
+            self.add_partitions(partition_list_with_correct_location)
+        except AlreadyExistsException:
+            pass
 
-    def create_database_if_not_exists(self, database: Database) -> bool:
+    def create_database_if_not_exists(self, database: Database) -> None:
         """
         Creates the table in Hive Metastore if it does not exist.
 
@@ -145,9 +159,24 @@ class HiveMetastoreClient(ThriftClient):
         """
         try:
             self.create_database(database)
-            return True
         except AlreadyExistsException:
-            return False
+            pass
+
+    def create_external_table(self, table: Table) -> None:
+        """
+        Creates an external table in Hive Metastore.
+
+        When a table is created with tableType default (None) or equal to
+         EXTERNAL_TABLE there is an error in the server that creates the table
+         as a MANAGED_TABLE.
+        This method enforces the parameter EXTERNAL=TRUE so the table is
+         created correctly.
+
+        :param table: the table object
+        """
+        table.parameters = {"EXTERNAL": "TRUE"}
+        table.tableType = "EXTERNAL_TABLE"
+        self.create_table(table)
 
     @staticmethod
     def _format_partitions_location(
@@ -198,4 +227,101 @@ class HiveMetastoreClient(ThriftClient):
         :param list_b: second list to be compared
         """
         if len(list_a) != len(list_b):
-            raise ValueError("The length of the two provided lists does not match")
+            raise ValueError(
+                "m=_validate_lists_length, msg=The length of the two provided "
+                "lists does not match"
+            )
+
+    def get_partition_keys_objects(
+        self, db_name: str, table_name: str
+    ) -> List[FieldSchema]:
+        """
+        Gets the partition keys objects, containing the metadata, from a table.
+
+        An empty list will be returned when no table is found or
+        when the table has no partitions
+
+        :param db_name: database name where the table is at
+        :param table_name: table name which the partition keys belong to
+        """
+        table = self.get_table(dbname=db_name, tbl_name=table_name)
+        return list(table.partitionKeys) if table else []
+
+    def get_partition_keys_names(self, db_name: str, table_name: str) -> List[str]:
+        """
+        Gets the partition keys names from a table.
+
+        An empty list will be returned when no table is found or
+        when the table has no partitions
+
+        :param db_name: database name where the table is at
+        :param table_name: table name which the partition keys belong to
+        """
+        partition_keys = self.get_partition_keys_objects(
+            db_name=db_name, table_name=table_name
+        )
+        return [partition.name for partition in partition_keys]
+
+    def bulk_drop_partitions(
+        self,
+        db_name: str,
+        table_name: str,
+        partition_list: List[List[str]],
+        delete_data: bool = False,
+    ) -> None:
+        """
+        Drops the partitions values from the partition list.
+
+        This methods simulates a bulk drop for the user, since the server only
+         supports an unitary drop.
+        If some partition cannot be dropped an exception will be thrown in the
+         end of execution.
+
+        :param db_name: database name of the table
+        :param table_name: table name
+        :param partition_list: the partitions to be dropped
+        :param delete_data: indicates whether the data respective to the
+         partition should be dropped in the source.
+        :raises: NoSuchObjectException
+        """
+        partitions_not_dropped = []
+        for partition_values in partition_list:
+            try:
+                self.drop_partition(db_name, table_name, partition_values, delete_data)
+            except NoSuchObjectException:
+                partitions_not_dropped.append(partition_values)
+
+        if partitions_not_dropped:
+            raise NoSuchObjectException(
+                "m=bulk_drop_partitions, partitions_not_dropped="
+                f"{partitions_not_dropped}, msg=Some partition values were not "
+                "dropped because they do not exist."
+            )
+
+    def get_partition_values_from_table(
+        self, db_name: str, table_name: str
+    ) -> List[List[str]]:
+        """
+        Gets the partition names from a table.
+
+        It automatically fetches the table's partition keys.
+
+        An empty list will be returned when no table is found or
+        when the table has no partitions.
+
+        :param db_name: database name where the table is at
+        :param table_name: table name which the partitions belong to
+        """
+        partition_values_response = self.get_partition_values(
+            PartitionValuesRequest(
+                dbName=db_name,
+                tblName=table_name,
+                partitionKeys=self.get_partition_keys_objects(
+                    db_name=db_name, table_name=table_name
+                ),
+            )
+        )
+
+        return [
+            partition.row for partition in partition_values_response.partitionValues
+        ]
